==> openGion_dev_5.9.14.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF64S.sql <==
/****************************************************************************/
/* GF64 ( ﾀｽｸﾂﾘｰ )                                                          */
/*                                                                          */
/* Created : 2016/11/04 10:32:20                                            */
/****************************************************************************/
CREATE TABLE GF64 (
   PRJCODE      varchar           (   30 )                                      /*  10 PRJｺｰﾄﾞ      */
 , TASK_ID      INTEGER                                                         /*  20 ﾀｽｸID        */
 , SEQ          INTEGER                         DEFAULT 0   NOT NULL            /*  30 順           */
 , TASK_LEVEL   INTEGER                                                         /*  40 ﾚﾍﾞﾙ         */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , MEETING      varchar           (    1 )      DEFAULT 0                       /*  60 ﾏｲﾙｽﾄｰﾝ      */
 , DYSTART      varchar           (   14 )                                      /*  70 開始日       */
 , DURATION     decimal                                                         /*  80 期間         */
 , COMPLETE     INTEGER                                                         /*  90 進捗率       */
 , PRIORITY     varchar           (    1 )                                      /* 100 優先度       */
 , NOTES        varchar           ( 4000 )                                      /* 110 ﾉｰﾄ          */
 , COLOR        varchar           (   50 )                                      /* 120 色記号       */
 , SHAPE        varchar           (   16 )                                      /* 130 模様         */
 , DEPEND_ID1   INTEGER                                                         /* 140 先行ﾀｽｸID1   */
 , DEPEND_TYPE1 varchar           (    1 )                                      /* 150 先行ﾀｽｸﾀｲﾌﾟ1 */
 , DEPEND_ID2   INTEGER                                                         /* 160 先行ﾀｽｸID2   */
 , DEPEND_TYPE2 varchar           (    1 )                                      /* 170 先行ﾀｽｸﾀｲﾌﾟ2 */
 , DEPEND_ID3   INTEGER                                                         /* 180 先行ﾀｽｸID3   */
 , DEPEND_TYPE3 varchar           (    1 )                                      /* 190 先行ﾀｽｸﾀｲﾌﾟ3 */
 , DEPEND_ID4   INTEGER                                                         /* 200 先行ﾀｽｸID4   */
 , DEPEND_TYPE4 varchar           (    1 )                                      /* 210 先行ﾀｽｸﾀｲﾌﾟ4 */
 , DEPEND_ID5   INTEGER                                                         /* 220 先行ﾀｽｸID5   */
 , DEPEND_TYPE5 varchar           (    1 )                                      /* 230 先行ﾀｽｸﾀｲﾌﾟ5 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/gf/db/sqlserver/sql/install/01_TABLE/GF64S.sql <==
/****************************************************************************/
/* GF64 ( ﾀｽｸﾂﾘｰ )                                                          */
/*                                                                          */
/* Created : 2017/04/07 09:50:29                                            */
/****************************************************************************/
CREATE TABLE GF64 (
   PRJCODE      varchar           (   30 )                                      /*  10 PRJｺｰﾄﾞ      */
 , TASK_ID      INTEGER                                                         /*  20 ﾀｽｸID        */
 , SEQ          INTEGER                         DEFAULT 0   NOT NULL            /*  30 順           */
 , TASK_LEVEL   INTEGER                                                         /*  40 ﾚﾍﾞﾙ         */
 , NAME_JA      varchar           (  200 )                                      /*  50 名称         */
 , MEETING      varchar           (    1 )      DEFAULT '0'                     /*  60 ﾏｲﾙｽﾄｰﾝ      */
 , DYSTART      varchar           (   14 )                                      /*  70 開始日       */
 , DURATION     decimal                                                         /*  80 期間         */
 , COMPLETE     INTEGER                                                         /*  90 進捗率       */
 , PRIORITY     varchar           (    1 )                                      /* 100 優先度       */
 , NOTES        varchar           ( 4000 )                                      /* 110 ﾉｰﾄ          */
 , COLOR        varchar           (   50 )                                      /* 120 色記号       */
 , SHAPE        varchar           (   16 )                                      /* 130 模様         */
 , DEPEND_ID1   INTEGER                                                         /* 140 先行ﾀｽｸID1   */
 , DEPEND_TYPE1 varchar           (    1 )                                      /* 150 先行ﾀｽｸﾀｲﾌﾟ1 */
 , DEPEND_ID2   INTEGER                                                         /* 160 先行ﾀｽｸID2   */
 , DEPEND_TYPE2 varchar           (    1 )                                      /* 170 先行ﾀｽｸﾀｲﾌﾟ2 */
 , DEPEND_ID3   INTEGER                                                         /* 180 先行ﾀｽｸID3   */
 , DEPEND_TYPE3 varchar           (    1 )                                      /* 190 先行ﾀｽｸﾀｲﾌﾟ3 */
 , DEPEND_ID4   INTEGER                                                         /* 200 先行ﾀｽｸID4   */
 , DEPEND_TYPE4 varchar           (    1 )                                      /* 210 先行ﾀｽｸﾀｲﾌﾟ4 */
 , DEPEND_ID5   INTEGER                                                         /* 220 先行ﾀｽｸID5   */
 , DEPEND_TYPE5 varchar           (    1 )                                      /* 230 先行ﾀｽｸﾀｲﾌﾟ5 */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET        varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET       varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET       varchar           (   10 )                                      /* 850 作成社員     */
 , DYUPD        varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD        varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD       varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD       varchar           (   10 )                                      /* 890 更新者       */
);
